bbprep.generators.SelectorDistanceScanner
=========================================

.. currentmodule:: bbprep.generators

.. autoclass:: SelectorDistanceScanner
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~SelectorDistanceScanner.generate_conformers
   
   

   
   
   